is.etx_class: Check classes of objects

View source: R/gen_class_checks.R

is.etx_classR Documentation

Check classes of objects

Description

These are a suite of functions which are to check the class of objects Mainly these are for allowing for functions to accept different types

Usage

is.etx_class(input, classCheck)

Arguments

input

the input of object to class check

classCheck

the class to check against


TheAlexBarth/EcotaxaTools documentation built on Nov. 14, 2024, 8:27 p.m.