trap_integrate: Trapezoidal integration

View source: R/gen_integration-tools.R

trap_integrateR Documentation

Trapezoidal integration

Description

This exists in a much more comprehensive way in dan kelley's oce but i hate using too many packages

Usage

trap_integrate(x, y, min_x, max_x, ...)

Arguments

x

typically this should be depth

y

typically this should be n/m3 or mg/m3

min_x

expands the first y value to this value

max_x

expands the last y value to this value

...

arguements to pass to integrate : most helpful to increase subdivisons or rel.tol

Author(s)

Alex Barth


TheAlexBarth/EcotaxaTools documentation built on Nov. 14, 2024, 8:27 p.m.