View source: R/gen_class_checks.R
| is.etx_class | R Documentation |
These are a suite of functions which are to check the class of objects Mainly these are for allowing for functions to accept different types
is.etx_class(input, classCheck)
input |
the input of object to class check |
classCheck |
the class to check against |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.