View source: R/gen_integration-tools.R
| trap_integrate | R Documentation |
This exists in a much more comprehensive way in dan kelley's oce but i hate using too many packages
trap_integrate(x, y, min_x, max_x, ...)
x |
typically this should be depth |
y |
typically this should be n/m3 or mg/m3 |
min_x |
expands the first y value to this value |
max_x |
expands the last y value to this value |
... |
arguements to pass to |
Alex Barth
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.